import { customEvent } from '@genesislcap/foundation-events';
import { Form } from '@genesislcap/foundation-forms';
import { html, ref, when } from '@microsoft/fast-element';
import { List } from '../list';
List;
Form;
/**
 * Default header for Entity Management screen
 * @internal
 */
export const defaultHeader = (prefix) => html `
  <h3 class="header-title">${(x) => x.title}</h3>
  ${when((x) => x.createEvent, html `
      <${prefix}-button class="add-button" appearance="neutral" @click=${(x, y) => x.createEntity()}>
        <${prefix}-icon size="lg" name="plus"></${prefix}-icon>
        Add
      </${prefix}-button>
    `)}
`;
/**
 * Header with search-bar for Entity Management screen
 * @internal
 */
export const searchBarHeader = (prefix) => html `
  <h3 class="header-title">${(x) => x.title}</h3>
  <div class="search-container">
    <${prefix}-search-bar
      :options="${(x) => x.searchBarConfig}"
      @selectionChange=${(x, ctx) => x.searchChanged(customEvent(ctx))}
    ></${prefix}-search-bar>
    ${when((x) => x.createEvent, html `
        <${prefix}-button class="add-button" appearance="neutral" @click=${(x, y) => x.createEntity()}>
          <${prefix}-icon size="lg" name="plus"></${prefix}-icon>
          Add
        </${prefix}-button>
      `)}
  </div>
`;
/**
 * Defines the html of the entity component as a ViewTemplate object
 * @typeParam EntityManagement - the {@link EntityManagement | class} the template is defined for
 */
export const getPrefixedEntities = (prefix) => html `
  <div class="container">
    <slot name="header" part="header">${(x) => x.headerTempalate}</slot>
    <entity-list
      title=${(x) => x.title}
      async-add=${(x) => x.asyncAdd}
      async-remove=${(x) => x.asyncRemove}
      async-update=${(x) => x.asyncUpdate}
      enable-cell-flashing=${(x) => x.enableCellFlashing}
      enable-row-flashing=${(x) => x.enableRowFlashing}
      persist-column-state-key=${(x) => x.persistColumnStateKey}
      row-selection=${(x) => x.rowSelection}
      size-columns-to-fit=${(x) => x.sizeColumnsToFit}
      enable-filter-bar=${(x) => x.enableFilterBar}
      resourceName=${(x) => x.resourceName}
      :deleteEvent=${(x) => x.deleteEvent}
      :updateEvent=${(x) => x.updateEvent}
      :gridOptions=${(x) => x.gridOptions}
      :columns=${(x) => x.columns}
      :datasourceConfig=${(x) => x.datasourceConfig}
      design-system-prefix=${prefix}
      data-test-id="entity-list"
      hide-edit=${(x) => x.hideEdit}
      hide-delete=${(x) => x.hideDelete}
      header-case-type=${(x) => x.headerCaseType}
    >
      <slot name="header" slot="header">${defaultHeader}</slot>
    </entity-list>
    <${prefix}-modal
      ${ref('editEntityModal')}
      class="edit-modal"
      position=${(x) => x.modalPosition}
      :onCloseCallback=${(x) => x.closeModal.bind(x)}
      data-test-id="edit-entity-modal"
    >
      <div slot="top" data-test-id="dialog-title">${(x) => x.editDialogTitle}</div>

      <slot name="edit">
        ${when((x) => x.editModalVisible, html `
            <foundation-form
              part="form"
              :renderers=${(x) => x.formRenderers}
              resourceName=${(x) => x.formResourceName}
              :data=${(x) => x.editedEntity}
              design-system-prefix=${prefix}
              :uischema=${(x) => x.formUiSchema}
              readonly=${(x) => x.readonly}
              @submit-success=${(x, c) => x.submitEntityChanges(c.event)}
            ></foundation-form>
          `)}
      </slot>
    </${prefix}-modal>
  </div>
`;
/** @internal */
export const template = html `
  ${(x) => getPrefixedEntities(x.prefix)}
`;
